@@ -162,9 +162,6 @@ octosql "SELECT * FROM plugins.plugins"`,
 		databases["docs"] = func() (physical.Database, error) {
 			return docs.Creator(ctx)
 		}
-		databases["lines"] = func() (physical.Database, error) {
-			return lines.Creator(ctx)
-		}
 
 		for _, metadata := range installedPlugins {
 			if _, ok := databases[metadata.Reference.Name]; ok {
@@ -192,9 +189,11 @@ octosql "SELECT * FROM plugins.plugins"`,
 			return fmt.Errorf("couldn't get file extension handlers: %w", err)
 		}
 		fileHandlers := map[string]func(name string, options map[string]string) (physical.DatasourceImplementation, physical.Schema, error){
-			"csv":     csv.Creator,
+			"csv":     csv.Creator(','),
 			"json":    json.Creator,
+			"lines":   lines.Creator,
 			"parquet": parquet.Creator,
+			"tsv":     csv.Creator('\t'),
 		}
 		for ext, pluginName := range fileExtensionHandlers {
 			fileHandlers[ext] = func(name string, options map[string]string) (physical.DatasourceImplementation, physical.Schema, error) {
@@ -205,6 +204,16 @@ octosql "SELECT * FROM plugins.plugins"`,
 				return db.GetTable(ctx, name, options)
 			}
 		}
+		for name := range fileHandlers {
+			curHandler := fileHandlers[name]
+			if _, ok := databases[name]; !ok {
+				databases[name] = func() (physical.Database, error) {
+					return &fileTypeDatabaseCreator{
+						creator: curHandler,
+					}, nil
+				}
+			}
+		}
 
 		env := physical.Environment{
 			Aggregates: aggregates.Aggregates,
@@ -290,7 +299,11 @@ octosql "SELECT * FROM plugins.plugins"`,
 				physicalPlan.Schema.Fields[i].Name = reverseMapping[physicalPlan.Schema.Fields[i].Name]
 			}
 			executionPlan = &DescribeNode{
-				Schema: physicalPlan.Schema,
+				Schema: physical.Schema{
+					Fields:        formats.WithoutQualifiers(physicalPlan.Schema.Fields),
+					TimeField:     physicalPlan.Schema.TimeField,
+					NoRetractions: physicalPlan.Schema.NoRetractions,
+				},
 			}
 			outSchema = DescribeNodeSchema
 		} else {
@@ -371,12 +384,17 @@ octosql "SELECT * FROM plugins.plugins"`,
 			if limitExpression != nil {
 				val, err := (*limitExpression).Evaluate(execCtx)
 				if err != nil {
-
+					return fmt.Errorf("couldn't evaluate limit expression: %w", err)
 				}
 				if val.Int < 0 {
 					return fmt.Errorf("limit must be positive, got %d", val.Int)
 				}
 				limit = &val.Int
+
+				if len(orderByExpressions) == 0 && physicalPlan.Schema.NoRetractions {
+					// We want short-circuiting.
+					executionPlan = nodes.NewLimit(executionPlan, *limitExpression)
+				}
 			}
 
 			sink = batch.NewOutputPrinter(
@@ -384,6 +402,7 @@ octosql "SELECT * FROM plugins.plugins"`,
 				orderByExpressions,
 				logical.DirectionsToMultipliers(outputOptions.OrderByDirections),
 				limit,
+				physicalPlan.Schema.NoRetractions,
 				outSchema,
 				func(writer io.Writer) batch.Format {
 					return formats.NewTableFormatter(writer)
@@ -392,7 +411,7 @@ octosql "SELECT * FROM plugins.plugins"`,
 			)
 		case "csv", "json":
 			if len(orderByExpressions) > 0 || (limitExpression != nil && !physicalPlan.Schema.NoRetractions) {
-				executionPlan = nodes.NewOrderSensitiveTransform(executionPlan, orderByExpressions, logical.DirectionsToMultipliers(outputOptions.OrderByDirections), limitExpression)
+				executionPlan = nodes.NewOrderSensitiveTransform(executionPlan, orderByExpressions, logical.DirectionsToMultipliers(outputOptions.OrderByDirections), limitExpression, physicalPlan.Schema.NoRetractions)
 			} else if limitExpression != nil {
 				executionPlan = nodes.NewLimit(executionPlan, *limitExpression)
 			}
@@ -417,7 +436,7 @@ octosql "SELECT * FROM plugins.plugins"`,
 
 		case "stream_native":
 			if len(orderByExpressions) > 0 || (limitExpression != nil && !physicalPlan.Schema.NoRetractions) {
-				executionPlan = nodes.NewOrderSensitiveTransform(executionPlan, orderByExpressions, logical.DirectionsToMultipliers(outputOptions.OrderByDirections), limitExpression)
+				executionPlan = nodes.NewOrderSensitiveTransform(executionPlan, orderByExpressions, logical.DirectionsToMultipliers(outputOptions.OrderByDirections), limitExpression, physicalPlan.Schema.NoRetractions)
 			} else if limitExpression != nil {
 				executionPlan = nodes.NewLimit(executionPlan, *limitExpression)
 			}
@@ -457,7 +476,7 @@ func init() {
 	rootCmd.Flags().BoolVar(&describe, "describe", false, "Describe query output schema.")
 	rootCmd.Flags().IntVar(&explain, "explain", 0, "Describe query output schema.")
 	rootCmd.Flags().BoolVar(&optimize, "optimize", true, "Whether OctoSQL should optimize the query.")
-	rootCmd.Flags().StringVar(&output, "output", "live_table", "Output format to use. Available options are live_table, batch_table, csv, json and stream_native.")
+	rootCmd.Flags().StringVarP(&output, "output", "o", "live_table", "Output format to use. Available options are live_table, batch_table, csv, json and stream_native.")
 	rootCmd.Flags().StringVar(&prof, "profile", "", "Enable profiling of the given type: cpu, memory, trace.")
 }
 
@@ -488,3 +507,15 @@ func typecheckExpr(ctx context.Context, expr logical.Expression, env physical.En
 	)
 	return physicalExpr, nil
 }
+
+type fileTypeDatabaseCreator struct {
+	creator func(name string, options map[string]string) (physical.DatasourceImplementation, physical.Schema, error)
+}
+
+func (f *fileTypeDatabaseCreator) ListTables(ctx context.Context) ([]string, error) {
+	return nil, nil
+}
+
+func (f *fileTypeDatabaseCreator) GetTable(ctx context.Context, name string, options map[string]string) (physical.DatasourceImplementation, physical.Schema, error) {
+	return f.creator(name, options)
+}
