@@ -3,7 +3,9 @@ package logical
 import (
 	"context"
 	"fmt"
+	"time"
 
+	"github.com/cube2222/octosql/execution"
 	"github.com/cube2222/octosql/octosql"
 	"github.com/cube2222/octosql/physical"
 )
@@ -95,6 +97,29 @@ func (ds *DataSource) Typecheck(ctx context.Context, env physical.Environment, l
 		return cte.Node, cte.UniqueVariableMapping
 	}
 
+	if ds.name == "dual" {
+		uniqueDummy := logicalEnv.GetUnique("dummy")
+		return physical.Node{
+				Schema: physical.NewSchema(
+					[]physical.SchemaField{
+						{
+							Name: uniqueDummy,
+							Type: octosql.String,
+						},
+					},
+					-1,
+				),
+				NodeType: physical.NodeTypeInMemoryRecords,
+				InMemoryRecords: &physical.InMemoryRecords{
+					Records: []execution.Record{
+						execution.NewRecord([]octosql.Value{octosql.NewString("X")}, false, time.Time{}),
+					},
+				},
+			}, map[string]string{
+				"dummy": uniqueDummy,
+			}
+	}
+
 	datasource, schema, err := env.Datasources.GetDatasource(ctx, ds.name, ds.options)
 	if err != nil {
 		panic(fmt.Errorf("couldn't create datasource: %v", err))
